===================
django-geopostcodes
===================


.. image:: https://img.shields.io/pypi/v/django_geopostcodes.svg
        :target: https://pypi.python.org/pypi/django_geopostcodes

.. image:: https://img.shields.io/travis/alexhayes/django_geopostcodes.svg
        :target: https://travis-ci.com/alexhayes/django_geopostcodes

.. image:: https://readthedocs.org/projects/django-geopostcodes/badge/?version=latest
        :target: https://django-geopostcodes.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

Django modelling for GeoPostcodes_

NOTE: This repository does not include the actual data, you must purchase this from geopostcodes.com and then import it, as per the documentation at django-geopostcodes.readthedocs.org

* Free software: MIT license
* Documentation: https://django-geopostcodes.readthedocs.io.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _GeoPostcodes: https://www.geopostcodes.com/
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
